@@ -3,7 +3,7 @@ seperate int large blocks for detail parsing
 
 input data will be seperated to
 
-  config(1):
+  initial_config(1):
     starts with: MARLOWE: Atomic Collisions ...
     ends with: Initial State of RANX = ...
 
@@ -94,6 +94,7 @@ import math
 
 from . import linereducer
 
+from . import initial_config
 from . import cascade_summary
 from . import cascade_detail_projectile
 from . import cascade_report_summary
@@ -193,8 +194,8 @@ class CascadeBaseState(BaseState):
 class Initial(BaseState):
     name = 'initial'
 
-class Config(RootBaseState):
-    name = 'config'
+class InitialConfig(RootBaseState):
+    name = 'initial_config'
 
     def startswith(self, line):
         match = re.compile(r'MARLOWE: Atomic Collisions in Solids in the Binary Collision Approximation')
@@ -204,9 +205,20 @@ class Config(RootBaseState):
         super().on_enter(line)
         logger.info(f'block:{self.name}') 
 
+    def on_exit(self):
+        # dump text
+        super().on_exit()
+
+        # parse initial_config block and set result
+        self.context.initial_config = initial_config.parse(self.textbuf.getvalue())
+
+        # save as initial_config.json file
+        self.context.on_initial_end()
+
 class Cascade(BaseState):
     name = 'cascade'
-    match = re.compile(r'Cascade\s*(?P<Cascade>\d+):     Group\s*(?P<Group>\d+)\s+Number\s*(?P<Number>\d+)')
+    # cascade/detail.mfs DETL2930
+    match = re.compile(r'Cascade\s*(?P<Cascade>\d+):\s{5}Group\s*(?P<Group>\d+)\s{6}Number\s*(?P<Number>\d+)')
 
     def startswith(self, line):
         return self.match.fullmatch(line)
@@ -222,10 +234,11 @@ class Cascade(BaseState):
 
 class CascadeSummary(CascadeBaseState):
     name = 'cascade_summary'
+    # cascade/detail.mfs DETL2930
+    match = re.compile(r'Cascade\s*\d+:\s{5}Group\s*\d+\s{6}Number\s*\d+')
 
     def startswith(self, line):
-        match = re.compile(r'Cascade\s*\d+:\s{5}Group\s*\d+\s{6}Number\s*\d+')
-        return match.fullmatch(line)
+        return self.match.fullmatch(line)
 
     def on_exit(self):
         # dump text
@@ -1059,9 +1072,17 @@ class Context():
             csv_cascade_ranger.writerow(csv_header.cascade_ranger_all)
             csv_cascade_ranger.writerow(rowdata)
 
+    def on_initial_end(self):
+        obj = {
+            'initial_config': self.initial_config
+                }
+        with (self.outputdir / 'initial.json').open('wt') as f:
+            json.dump(obj, f, indent=2)
+
 
     def on_final_end(self):
         obj = {
+            'initial_config': self.initial_config,
             'final_rangex': self.final_rangex,
             'final_slavex': self.final_slavex,
             'final_sequex': self.final_sequex,
@@ -1115,7 +1136,7 @@ class BlockSeparator():
 
     def build_states(self):
         self.initial = Initial(self.context)
-        self.config = Config(self.context)
+        self.initial_config = InitialConfig(self.context)
         self.cascade = Cascade(self.context)
         self.cascade_summary = CascadeSummary(self.context)
         self.cascade_detail_initial_defect = CascadeDetailInitialDefect(self.context)
@@ -1142,8 +1163,8 @@ class BlockSeparator():
         self.final_end = FinalEnd(self.context)
         self.end = End(self.context)
 
-        self.initial.next_states = [self.config]
-        self.config.next_states = [self.cascade]
+        self.initial.next_states = [self.initial_config]
+        self.initial_config.next_states = [self.cascade]
         self.cascade.next_states = [self.cascade_summary]
         self.cascade_summary.next_states = [
                 self.cascade_detail_initial_defect,
