@@ -64,8 +64,9 @@ seqn_replacement_seq_indeterminate_direction:\
 seqn_replacement_seq_all_1:\
     "Equivalent directions are combined where possible" _NL
 seqn_replacement_seq_all_2:\
-    "<" fwint3 ":" (fwint3)~3 ">" _S SEQN4310_2 fwint4 _SS~8 SEQN4310_3 fwint5 _SS~8 SEQN4310_4 fwint4 SEQN4310_5 fwint5 _NL\
+    "<" fwint3 ":" seqn_narrow_3i3 ">" _S SEQN4310_2 fwint4 _SS~8 SEQN4310_3 fwint5 _SS~8 SEQN4310_4 fwint4 SEQN4310_5 fwint5 _NL\
     int_multiline_array20
+seqn_narrow_3i3: /[ \\d\\*+-]+/
 
 SEQN3060: "No focuson events were found"
 SEQN3180: "No replacement events were found"
@@ -261,7 +262,7 @@ class Transformer(lark_common.Transformer):
     def seqn_replacement_seq_all_2(self, args):
         ''' "<"
         fwint3 ":"
-        (fwint3)~3 ">" _S SEQN4310_2 _S
+        seqn_narrow_3i3 ">" _S SEQN4310_2 _S
         pint _S SEQN4310_3 _S
         pint _S SEQN4310_4 _S
         pint SEQN4310_5 _S
@@ -269,14 +270,37 @@ class Transformer(lark_common.Transformer):
         int_multiline_array20'''
         obj = {
                 'Index': args[0],
-                'Vector': args[1:4],
-                'First Channel':args[5],
-                'Maximum Length':args[7],
-                'Long Sequence Threshold':args[9],
-                'Long Sequence Count':args[11],
-                'data':args[12].children}
+                'Vector': args[1],
+                'First Channel':args[3],
+                'Maximum Length':args[5],
+                'Long Sequence Threshold':args[7],
+                'Long Sequence Count':args[9],
+                'data':args[10].children}
         return obj
 
+    def seqn_narrow_3i3(self, args):
+        return self.parse_narrow_3I3(args[0])
+
+    @staticmethod
+    def parse_narrow_3I3(text):
+        '''parse 3I3 format
+        text: input text, which may be formatted in 3I3, or 3(X,I)
+        return: [int, int, int]
+        '''
+
+        # first, simply split text with WS.
+        sp = text.split()
+        if len(sp) < 3:
+            # assume some values are concatinated
+            # it may consists '*', which shall be replaced to 9 (see, lark_common.gen_fixedwidth_int_reciever())
+            sp = [text[i:i+3].replace('*', '9') for i in range(0, 9, 3)]
+        elif len(sp) > 3:
+            raise 'too match array elements'
+
+        # str -> int
+        return [int(s) for s in sp]
+
+
     def seqn_replacement_valid(self, args):
         obj = {}
         for a in args:
