@@ -6,7 +6,7 @@ import pathlib
 
 from marlowe_ui.postprocess_lark import cascade_summary
 
-class TestFinalSequex(unittest.TestCase):
+class TestCascadeSummary(unittest.TestCase):
     def setUp(self):
         self.current_dir = pathlib.Path(__file__).parent
 
@@ -14,7 +14,7 @@ class TestFinalSequex(unittest.TestCase):
     @parameterized.expand([
         ('01.cascade_summary.txt', '01.cascade_summary_out.json')
         ])
-    def test_final_sequex(self, filename, jsonfile):
+    def test_cascade_summary(self, filename, jsonfile):
         p = self.current_dir / 'cascade_summary_examples'/ filename
         jp = self.current_dir / 'cascade_summary_examples'/ jsonfile
         # print(p)
@@ -23,4 +23,3 @@ class TestFinalSequex(unittest.TestCase):
             result = cascade_summary.parse(f.read())
             jdata = json.load(jf)
             self.assertEqual(result, jdata)
-
